@@ -1,3 +1,8 @@
+"""
+Area Chart
+=========
+"""
+# category: basic marks
 import gosling as gos
 from gosling.data import multivec
 
