@@ -1,3 +1,8 @@
+"""
+Line Chart
+==========
+"""
+# category: basic marks
 import gosling as gos
 from gosling.data import multivec
 
