@@ -1,3 +1,8 @@
+"""
+Point Plot
+==========
+"""
+# category: basic marks
 import gosling as gos
 from gosling.data import multivec
 
